==> TprParser-0.1.48.tar.gz: TprParser-0.1.48/src/Reader.h <==
#ifndef READER_H
#define	 READER_H

#include "define.h"
#include "Bytes.h"
#include "TprData.h"
#include <string.h>
#include <cstdint>

#define INSERT_POS(prop) data_->property.prop = tpr_.ftell_()

class TprReader
{
public:
	const char* fout_ = nullptr;

public:
	// data_ memset㺬ģĽṹ
	TprReader(
		const char* fname,
		bool bGRO = false,
		bool bMol2 = false,
		bool bCharge = false
	)
		: tpr_(fname, "rb"), data_(new TprData), fout_("new.tpr"),
		bGRO_(bGRO), bMol2_(bMol2), bCharge_(bCharge)
	{
		if (tpr_header() != TPR_SUCCESS)
		{
			throw std::runtime_error("error for tpr_header()");
		}
		if (tpr_body() != TPR_SUCCESS)
		{
			throw std::runtime_error("error for tpr_body()");
		}
		if (tpr_mtop() != TPR_SUCCESS)
		{
			throw std::runtime_error("error for tpr_mtop()");
		}
		if (tpr_xvf() != TPR_SUCCESS)
		{
			throw std::runtime_error("error for tpr_xvf()");
		}
		if (tpr_chargemass() != TPR_SUCCESS)
		{
			throw std::runtime_error("error for tpr_chargemass()");
		}
		if (tpr_bonds() != TPR_SUCCESS)
		{
			throw std::runtime_error("error for tpr_bonds()");
		}
		if (tpr_angles() != TPR_SUCCESS)
		{
			throw std::runtime_error("error for tpr_angles()");
		}
		if (tpr_dihedrals() != TPR_SUCCESS)
		{
			throw std::runtime_error("error for tpr_dihedrals()");
		}
		if (do_ir() != TPR_SUCCESS)
		{
			throw std::runtime_error("error for do_ir()");
		}
	}

	~TprReader()
	{
		if (data_) delete data_;

		msg("End of TprReader\n");
	}

	// read header
	bool tpr_header();

	// read body of tpr
	bool tpr_body();

	// read mtop
	bool tpr_mtop();

	//< read coodinates, velocity and force of atoms
	bool tpr_xvf();

	//< dump charges and mass
	bool tpr_chargemass();

	//< dump bonds of tpr, can only store angle and harmonic force constant
	bool tpr_bonds();

	//< dump angles of tpr, can only store angle and harmonic force constant
	bool tpr_angles();

	/*  \brief dump ALL dihedrals of tpr.
	* Can not store dihedrals parameters
	*/
	bool tpr_dihedrals();

	//< do_ir
	bool do_ir();

public:
	//< change tpr file nsteps
	bool set_nsteps(int64_t nsteps);

	//< change tpr file dt (ps)
	bool set_dt(double dt);

	//< change tpr atomic coordinates
	bool set_xvf(const char* type, std::vector<float>& vec);

	//< set pressure coupling parts
	bool set_pressure(
		const char* method,
		const char* type,
		float tau_p,
		std::vector<float>& ref_p,
		std::vector<float>& compress);

	//< set temperature coupling parts. Have not yet set groups name
	bool set_temperature(
		const char* method,
		std::vector<float>& tau_t,
		std::vector<float>& ref_t);

	//< set integer mdp parameters
	bool set_mdp_integer(const char* prop, int val);

	//< 1. get coords/velocity/force/mass/charge
	//< 2. get box info in vector 9
	const std::vector<float>& get_xvf(const char* type) const;

	//< get resname, atomname
	const std::vector<std::string>& get_name(const char *type) const;

	//< get bonds/angles info in vector 
	std::vector<int> get_bonded(const char *type) const;

private:
	//< assistant func to write tpr given new coords, velocity or force
	bool write_xvf(std::vector<float>& vec, long pos, long prec) const;

	//< read forcefield parameters
	bool tpr_readff();

	//< read parameters
	bool do_iparams(int ftype, t_iparams * iparams, int filever, int prec);

	//< moltype dump
	bool do_atoms();

	//< atomtype
	bool do_atomtypes();

	//< read cmap
	bool do_cmap();

	//< read groups
	bool do_groups();

	//< do_ilists
	bool do_ilists(int ntype, std::vector<int>(&nr)[F_NRE], vecI2D(&interactionlist)[F_NRE]);

	//< do_fepvals
	bool do_fepvals();

private:
	FileSerializer			tpr_;
	TprData					*data_;
	std::vector<t_iparams>  iparams_; // 
	std::vector<int>		functype_; // 
	bool					bGRO_ = false; //< if write a gro
	bool					bMol2_ = false; //< if write a mol2 whith bonds
	bool					bCharge_ = false; //< if write atomic charge and mass to file
};

#endif // !READER_H

==> TprParser-0.1.49.tar.gz: TprParser-0.1.49/src/Reader.h <==
#ifndef READER_H
#define	 READER_H

#include "define.h"
#include "Bytes.h"
#include "TprData.h"
#include <string.h>
#include <cstdint>

#define INSERT_POS(prop) data_->property.prop = tpr_.ftell_()

class TprReader
{
public:
	const char* fout_ = nullptr;

public:
	// data_ memset㺬ģĽṹ
	TprReader(
		const char* fname,
		bool bGRO = false,
		bool bMol2 = false,
		bool bCharge = false
	)
		: tpr_(fname, "rb"), data_{ new TprData() }, fout_("new.tpr"),
		bGRO_(bGRO), bMol2_(bMol2), bCharge_(bCharge)
	{
		if (tpr_header() != TPR_SUCCESS)
		{
			throw std::runtime_error("error for tpr_header()");
		}
		if (tpr_body() != TPR_SUCCESS)
		{
			throw std::runtime_error("error for tpr_body()");
		}
		if (tpr_mtop() != TPR_SUCCESS)
		{
			throw std::runtime_error("error for tpr_mtop()");
		}
		if (tpr_xvf() != TPR_SUCCESS)
		{
			throw std::runtime_error("error for tpr_xvf()");
		}
		if (tpr_chargemass() != TPR_SUCCESS)
		{
			throw std::runtime_error("error for tpr_chargemass()");
		}
		if (tpr_bonds() != TPR_SUCCESS)
		{
			throw std::runtime_error("error for tpr_bonds()");
		}
		if (tpr_angles() != TPR_SUCCESS)
		{
			throw std::runtime_error("error for tpr_angles()");
		}
		if (tpr_dihedrals() != TPR_SUCCESS)
		{
			throw std::runtime_error("error for tpr_dihedrals()");
		}
		if (do_ir() != TPR_SUCCESS)
		{
			throw std::runtime_error("error for do_ir()");
		}
	}

	~TprReader()
	{
		if (data_) delete data_;

		msg("End of TprReader\n");
	}

	// read header
	bool tpr_header();

	// read body of tpr
	bool tpr_body();

	// read mtop
	bool tpr_mtop();

	//< read coodinates, velocity and force of atoms
	bool tpr_xvf();

	//< dump charges and mass
	bool tpr_chargemass();

	//< dump bonds of tpr, can only store angle and harmonic force constant
	bool tpr_bonds();

	//< dump angles of tpr, can only store angle and harmonic force constant
	bool tpr_angles();

	/*  \brief dump ALL dihedrals of tpr.
	* Can not store dihedrals parameters
	*/
	bool tpr_dihedrals();

	//< do_ir
	bool do_ir();

public:
	//< change tpr file nsteps
	bool set_nsteps(int64_t nsteps);

	//< change tpr file dt (ps)
	bool set_dt(double dt);

	//< change tpr atomic coordinates
	bool set_xvf(const char* type, std::vector<float>& vec);

	//< set pressure coupling parts
	bool set_pressure(
		const char* method,
		const char* type,
		float tau_p,
		std::vector<float>& ref_p,
		std::vector<float>& compress);

	//< set temperature coupling parts. Have not yet set groups name
	bool set_temperature(
		const char* method,
		std::vector<float>& tau_t,
		std::vector<float>& ref_t);

	//< set integer mdp parameters
	bool set_mdp_integer(const char* prop, int val);

	//< 1. get coords/velocity/force/mass/charge
	//< 2. get box info in vector 9
	const std::vector<float>& get_xvf(const char* type) const;

	//< get resname, atomname
	const std::vector<std::string>& get_name(const char *type) const;

	//< get bonds/angles info in struct 
	const std::vector<Bonded> &get_bonded(const char *type) const;

private:
	//< assistant func to write tpr given new coords, velocity or force
	bool write_xvf(std::vector<float>& vec, long pos, long prec) const;

	//< read forcefield parameters
	bool tpr_readff();

	//< read parameters
	bool do_iparams(int ftype, t_iparams * iparams, int filever, int prec);

	//< moltype dump
	bool do_atoms();

	//< atomtype
	bool do_atomtypes();

	//< read cmap
	bool do_cmap();

	//< read groups
	bool do_groups();

	//< do_ilists
	bool do_ilists(int ntype, std::vector<int>(&nr)[F_NRE], vecI2D(&interactionlist)[F_NRE]);

	//< do_fepvals
	bool do_fepvals();

private:
	FileSerializer			tpr_;
	TprData					*data_ = nullptr;
	std::vector<t_iparams>  iparams_; // 
	std::vector<int>		functype_; // 
	bool					bGRO_ = false; //< if write a gro
	bool					bMol2_ = false; //< if write a mol2 whith bonds
	bool					bCharge_ = false; //< if write atomic charge and mass to file
};

#endif // !READER_H
